==> lms-1.5.0.tar.gz: lms/modules/tariffedit.php <==
<?php

/*
 * LMS version 1.5.0 Marduk
 *
 *  (C) Copyright 2001-2004 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: tariffedit.php,v 1.26 2004/09/18 19:21:28 alec Exp $
 */

if(!$LMS->TariffExists($_GET['id']))
{
	header('Location: ?m=tarifflist');
	die;
}

$tariff = $_POST['tariff'];

if(isset($tariff))
{
	foreach($tariff as $key => $value)
		$tariff[$key] = trim($value);

	$tariff['value'] = str_replace(',','.',$tariff['value']);
	
	if($tariff['uprate'] == '') $tariff['uprate'] = 0;
	if($tariff['upceil'] == '') $tariff['upceil'] = 0;
	if($tariff['downrate'] == '') $tariff['downrate'] = 0;
	if($tariff['downceil'] == '') $tariff['downceil'] = 0;
	if($tariff['climit'] == '') $tariff['climit'] = 0;
	if($tariff['plimit'] == '') $tariff['plimit'] = 0;

	if($tariff['name'] == '')
		$error['name'] = 'Prosz poda nazw taryfy!';
	elseif($LMS->GetTariffIDByName($tariff['name']) && $tariff['name'] != $LMS->GetTariffName($_GET['id']))
		$error['name'] = 'Istnieje ju taryfa o takiej nazwie!';	

	if($tariff['value'] == '')
		$error['value'] = 'Prosz poda warto!';
	elseif(!(ereg('^[-]?[0-9.,]+$', $tariff['value'])))
		$error['value'] = 'Podana warto jest niepoprawna!';
	
	if($tariff['taxvalue'] != '')
	  	if(!(ereg('^[0-9.,]+$', $tariff['taxvalue'])) || $tariff['taxvalue'] < 0 || $tariff['taxvalue'] > 100)
			$error['taxvalue'] = 'Podana stawka podatku jest niepoprawna!';

	if(!(ereg("^[0-9]+$", $tariff['uprate'])))
		$error['uprate'] = 'To pole musi zawiera liczb cakowit';
	if(!ereg('^[0-9]+$', $tariff['downrate']))
		$error['downrate'] = 'To pole musi zawiera liczb cakowit';
	if(!(ereg("^[0-9]+$", $tariff['upceil'])))
		$error['upceil'] = 'To pole musi zawiera liczb cakowit';
	if(!ereg('^[0-9]+$', $tariff['downceil']))
		$error['downceil'] = 'To pole musi zawiera liczb cakowit';
	if(!(ereg("^[0-9]+$", $tariff['climit'])))
		$error['climit'] = 'To pole musi zawiera liczb cakowit';
	if(!ereg('^[0-9]+$', $tariff['plimit']))
		$error['plimit'] = 'To pole musi zawiera liczb cakowit';
	
	if(($tariff['uprate'] < 8 || $tariff['uprate'] > 4096) && $tariff['uprate'] != 0)
		$error['uprate'] = 'To pole musi zawiera liczb z przedziau 8 - 4096';
	if(($tariff['downrate'] < 8 || $tariff['downrate'] > 4096) && $tariff['downrate'] != 0)
		$error['downrate'] = 'To pole musi zawiera liczb z przedziau 8 - 4096';
	if(($tariff['upceil'] < 8 || $tariff['upceil'] < $tariff['uprate']) && $tariff['upceil'] != 0)
		$error['upceil'] = 'To pole musi zawiera liczb wiksz od 8 i wiksz od upload rate';
	if(($tariff['downceil'] < 8 || $tariff['downceil'] < $tariff['downrate']) && $tariff['downceil'] != 0)
		$error['downceil'] = 'To pole musi zawiera liczb wiksz od 8 i wiksz od download rate';


	$tariff['id'] = $_GET['id'];

	if(!$error)
	{
		$LMS->TariffUpdate($tariff);
		header('Location: ?m=tariffinfo&id='.$tariff['id']);
		die;
	}

}else
	$tariff = $LMS->GetTariff($_GET['id']);
	
$layout['pagetitle'] = 'Edycja taryfy: '.$tariff['name'];	
$SMARTY->assign('tariff',$tariff);
$SMARTY->assign('error',$error);
$SMARTY->display('tariffedit.html');

?>

==> lms-1.8.0rc5.tar.gz: lms/modules/tariffedit.php <==
<?php

/*
 * LMS version 1.8.0rc5 Rosha
 *
 *  (C) Copyright 2001-2005 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: tariffedit.php,v 1.34.2.1 2005/12/07 08:56:21 alec Exp $
 */

if(!$LMS->TariffExists($_GET['id']))
{
	$SESSION->redirect('?m=tarifflist');
}

$tariff = $_POST['tariff'];

if(isset($tariff))
{
	foreach($tariff as $key => $value)
		$tariff[$key] = trim($value);

	$tariff['value'] = str_replace(',','.',$tariff['value']);
	
	if($tariff['uprate'] == '') $tariff['uprate'] = 0;
	if($tariff['upceil'] == '') $tariff['upceil'] = 0;
	if($tariff['downrate'] == '') $tariff['downrate'] = 0;
	if($tariff['downceil'] == '') $tariff['downceil'] = 0;
	if($tariff['climit'] == '') $tariff['climit'] = 0;
	if($tariff['plimit'] == '') $tariff['plimit'] = 0;

	if($tariff['name'] == '')
		$error['name'] = trans('Subscription name required!');
	elseif($LMS->GetTariffIDByName($tariff['name']) && $tariff['name'] != $LMS->GetTariffName($_GET['id']))
		$error['name'] = trans('Subscription with specified name already exists!');

	if($tariff['value'] == '')
		$error['value'] = trans('Value required!');
	elseif(!(ereg('^[-]?[0-9.,]+$', $tariff['value'])))
		$error['value'] = trans('Incorrect value!');
	
	if(!(ereg("^[0-9]+$", $tariff['uprate'])))
		$error['uprate'] = trans('Integer value expected!');
	if(!ereg('^[0-9]+$', $tariff['downrate']))
		$error['downrate'] = trans('Integer value expected!');
	if(!(ereg("^[0-9]+$", $tariff['upceil'])))
		$error['upceil'] = trans('Integer value expected!');
	if(!ereg('^[0-9]+$', $tariff['downceil']))
		$error['downceil'] = trans('Integer value expected!');
	if(!(ereg("^[0-9]+$", $tariff['climit'])))
		$error['climit'] = trans('Integer value expected!');
	if(!ereg('^[0-9]+$', $tariff['plimit']))
		$error['plimit'] = trans('Integer value expected!');
	
	if(($tariff['uprate'] < 8 || $tariff['uprate'] > 4096) && $tariff['uprate'] != 0)
		$error['uprate'] = trans('This field must be within range 8 - 4096');
	if(($tariff['downrate'] < 8 || $tariff['downrate'] > 4096) && $tariff['downrate'] != 0)
		$error['downrate'] = trans('This field must be within range 8 - 4096');
	if(($tariff['upceil'] < 8 || $tariff['upceil'] < $tariff['uprate']) && $tariff['upceil'] != 0)
		$error['upceil'] = trans('This field must be greater than 8 and greater than upload rate');
	if(($tariff['downceil'] < 8 || $tariff['downceil'] < $tariff['downrate']) && $tariff['downceil'] != 0)
		$error['downceil'] = trans('This field must be greater than 8 and greater than download rate');

	if(!$tariff['taxid'])
		$tariff['taxid'] = 0;

	$tariff['id'] = $_GET['id'];

	if(!$error)
	{
		$LMS->TariffUpdate($tariff);
		$SESSION->redirect('?m=tariffinfo&id='.$tariff['id']);
	}

}else
	$tariff = $LMS->GetTariff($_GET['id']);
	
$layout['pagetitle'] = trans('Subscription Edit: $0',$tariff['name']);

$SMARTY->assign('tariff',$tariff);
$SMARTY->assign('taxeslist',$LMS->GetTaxes());
$SMARTY->assign('error',$error);
$SMARTY->display('tariffedit.html');

?>
